<?php

declare(strict_types=1);

namespace Web200\Mailjet\Model\Webservice;

use Web200\Mailjet\Helper\Config;
use Web200\Mailjet\Logger\Logger;
use \Mailjet\Resources;
use \Mailjet\Client as MailjetClient;
use Magento\Framework\Exception\LocalizedException;

/**
 * Class Webservice
 *
 * @package   Web200\Mailjet\Model\Webservice
 * @author    Web200 <contact@web200.fr>
 * @copyright 2019 Web200
 * @license   https://opensource.org/licenses/osl-3.0.php Open Software License (OSL 3.0)
 * @link      https://www.web200.fr/
 */
class Webservice
{
    /**
     * @var string
     */
    protected $apiVersion = 'v3.1';
    /**
     * @var Config
     */
    protected $config;
    /**
     * @var Logger
     */
    protected $logger;
    /**
     * @var int
     */
    protected $storeId;

    /**
     * Webservice constructor.
     *
     * @param Logger  $logger
     * @param Config  $config
     */
    public function __construct(
        Logger $logger,
        Config $config
    ) {
        $this->config = $config;
        $this->logger = $logger;
    }

    /**
     * Init Api
     *
     * @param string $kind
     * @return MailjetClient
     * @throws LocalizedException
     */
    protected function initApi(string $kind): MailjetClient
    {
        $this->checkLogin($kind);

        $api = new MailjetClient(
            $this->config->getApiKeyPublic($kind, $this->getStoreId()),
            $this->config->getApiKeyPrivate($kind, $this->getStoreId()),
            true,
            ['version' => $this->apiVersion]
        );
        return $api;
    }

    /**
     * Check login information
     *
     * @param string $kind
     * @return bool
     * @throws LocalizedException
     */
    protected function checkLogin(string $kind): bool
    {
        if ($this->config->getApiKeyPublic($kind, $this->getStoreId()) === '') {
            throw new LocalizedException(__('Api Public Key empty'));
        }
        if ($this->config->getApiKeyPrivate($kind, $this->getStoreId()) === '') {
            throw new LocalizedException(__('Api Secret Key empty'));
        }
        return true;
    }

    /**
     * @return int
     */
    public function getStoreId(): ?int
    {
        return $this->storeId;
    }

    /**
     * @param int $storeId
     * @return Email
     */
    public function setStoreId(int $storeId): Email
    {
        $this->storeId = $storeId;

        return $this;
    }
}
